histomicstk.preprocessing
=================================

.. automodule:: histomicstk.preprocessing
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
    :maxdepth: 1

    color space conversion <histomicstk.preprocessing.color_conversion>
    color deconvolution <histomicstk.preprocessing.color_deconvolution>
    color normalization <histomicstk.preprocessing.color_normalization>
    data augmentation <histomicstk.preprocessing.augmentation>

